==> dsgwd_pi.00.25.tar.gz: from_dprs.c <==
/*

*/

#include	"dsgwd_pi.h"
#include	"node_adapter.h"
#include	"node.h"
#include	"dprs.h"

extern	char    ConnectedMsg[13][12];

void	DprsMsgSendToRF ()
{
	int	i;
	char	buff[12], flags[3];
	char	tmp[40], MyCall[9], YourCall[8];
	char	DprsMyCall[8];
	char	len;


		if (mq_receive (dprs_qid, tmp, 40, NULL) == -1) return;
	
		/* Call Sign set */
		memset (MyCall, 0x20, 9);
		memset (YourCall, 0x20, 8);
		memset (DprsMyCall, 0x20, 9);
		for (i = 0 ; i < 9 ; i++)
		{
			if (tmp[i] == '>') break;
			if (tmp[i] == '-')
			{
				MyCall[i] = 0x20;
			} else {
				MyCall[i] = tmp[i];
			}
		}
		if (MyCall[8] != 0x20)
		{
			MyCall[6] = MyCall[7];
			MyCall[7] = MyCall[8];
		}				
		for (i = 0 ; i < 8 ; i++)
		{
			if (tmp[i+10] == '-') break;
			YourCall[i] = tmp[i+10];
		}
		for (i = 0 ; i < 9 ; i++)
		{
			if (tmp[i] == '>') break;
			DprsMyCall[i] = tmp[i];
		}

		flags[0] = 0x00;
		flags[1] = 0x00;
		flags[2] = 0x00;
        	usb_control_msg (0x40, SET_MyCALL, 0, 0, MyCall, 8, 100);
        	usb_control_msg (0x40, SET_MyCALL2, 0, 0, "APRS", 4, 100);
        	usb_control_msg (0x40, SET_YourCALL, 0, 0, YourCall, 8, 100);
        	usb_control_msg (0x40, SET_RPT2CALL, 0, 0, "DIRECT  ", 8, 100);
        	usb_control_msg (0x40, SET_RPT1CALL, 0, 0, client_call, 8, 100);
        	usb_control_msg (0x40, SET_FLAGS, 0, 0, flags, 3, 100);

		/* PTT ON */
		while (1)
		{
		   	usb_control_msg(0xC0, GET_REMAINSPACE, 0, 0, &len ,1, 100);
			if (len >=95)
			{
				usb_control_msg(0x40, SET_PTT, ON, 0, buff, 0, 100);
				PTT_On = TRUE;
				break;
			} else {
				return;
			}
		}

		for (i = 0 ; i < 11 ; i++)
		{
			//memcpy (buff, &ConnectedMsg[i][0], 12);
			switch (i)
			{
				case 1:
					buff[10] = tmp[20] ^ 0x4f;
					buff[11] = tmp[21] ^ 0x93;
					break;
				case 2:
					buff[ 9] = tmp[22] ^ 0x70;
					buff[10] = tmp[23] ^ 0x4f;
					buff[11] = tmp[24] ^ 0x93;
					break;
				case 3:
					buff[10] = tmp[25] ^ 0x4f;
					buff[11] = tmp[26] ^ 0x93;
					break;
				case 4:
					buff[ 9] = tmp[27] ^ 0x70;
					buff[10] = tmp[28] ^ 0x4f;
					buff[11] = tmp[29] ^ 0x93;
					break;
				case 5:
					buff[10] = tmp[30] ^ 0x4f;
					buff[11] = tmp[31] ^ 0x93;
					break;
				case 6:
					buff[ 9] = tmp[32] ^ 0x70;
					buff[10] = tmp[33] ^ 0x4f;
					buff[11] = tmp[34] ^ 0x93;
					break;
				case 7:
					buff[10] = tmp[35] ^ 0x4f;
					buff[11] = tmp[36] ^ 0x93;
					break;
				case 8:
					buff[ 9] = tmp[37] ^ 0x70;
					buff[10] = tmp[38] ^ 0x4f;
					buff[11] = tmp[39] ^ 0x93;
					break;
			}
			while (1)
			{
			   	usb_control_msg(0xC0, GET_REMAINSPACE, 0, 0, &len ,1, 100);
				if (len >= 12)
				{
					usb_control_msg(0x40, PUT_DATA, 0, 0, buff, 12, 100);
					break;
				} else {
					usleep (30000);
				}
			}
		}

		while (1)
		{
		   	usb_control_msg(0xC0, GET_REMAINSPACE, 0, 0, &len ,1, 100);
			if (len >= 15)
			{
				usb_control_msg(0x40, PUT_DATA, 0, 0, &ConnectedMsg[11][0], 15, 100);
				break;
			} else {
				usleep(50000);
			}
		}

		/* PTT OFF */
		usb_control_msg(0x40, SET_PTT, OFF, 0, buff, 0, 100);
		PTT_On = FALSE;
}

==> dsgwd_pi.00.26.tar.gz: from_dprs.c <==
/*

*/

#include	"dsgwd_pi.h"
#include	"node_adapter.h"
#include	"node.h"
#include	"dprs.h"

extern	char    ConnectedMsg[13][12];

void	DprsMsgSendToRF ()
{
	int	i;
	char	buff[12], flags[3];
	char	tmp[40], MyCall[9], YourCall[8];
	char	DprsMyCall[8];
	char	len;


		if (mq_receive (dprs_qid, tmp, 40, NULL) == -1) return;
	
		/* Call Sign set */
		memset (MyCall, 0x20, 9);
		memset (YourCall, 0x20, 8);
		memset (DprsMyCall, 0x20, 9);
		for (i = 0 ; i < 9 ; i++)
		{
			if (tmp[i] == '>') break;
			if (tmp[i] == '-')
			{
				MyCall[i] = 0x20;
			} else {
				MyCall[i] = tmp[i];
			}
		}
		if (MyCall[8] != 0x20)
		{
			MyCall[6] = MyCall[7];
			MyCall[7] = MyCall[8];
		}				
		for (i = 0 ; i < 8 ; i++)
		{
			if (tmp[i+10] == '-') break;
			YourCall[i] = tmp[i+10];
		}
		for (i = 0 ; i < 9 ; i++)
		{
			if (tmp[i] == '>') break;
			DprsMyCall[i] = tmp[i];
		}

		flags[0] = 0x00;
		flags[1] = 0x00;
		flags[2] = 0x00;
        	usb_control_msg (0x40, SET_MyCALL, 0, 0, MyCall, 8, 100);
        	usb_control_msg (0x40, SET_MyCALL2, 0, 0, "DPRS", 4, 100);
        	usb_control_msg (0x40, SET_YourCALL, 0, 0, YourCall, 8, 100);
        	usb_control_msg (0x40, SET_RPT2CALL, 0, 0, "DIRECT  ", 8, 100);
        	usb_control_msg (0x40, SET_RPT1CALL, 0, 0, client_call, 8, 100);
        	usb_control_msg (0x40, SET_FLAGS, 0, 0, flags, 3, 100);

		/* PTT ON */
		while (1)
		{
		   	usb_control_msg(0xC0, GET_REMAINSPACE, 0, 0, &len ,1, 100);
			if (len >=95)
			{
				usb_control_msg(0x40, SET_PTT, ON, 0, buff, 0, 100);
				PTT_On = TRUE;
				break;
			} else {
				return;
			}
		}

		for (i = 0 ; i < 11 ; i++)
		{
			//memcpy (buff, &ConnectedMsg[i][0], 12);
			switch (i)
			{
				case 1:
					buff[10] = tmp[20] ^ 0x4f;
					buff[11] = tmp[21] ^ 0x93;
					break;
				case 2:
					buff[ 9] = tmp[22] ^ 0x70;
					buff[10] = tmp[23] ^ 0x4f;
					buff[11] = tmp[24] ^ 0x93;
					break;
				case 3:
					buff[10] = tmp[25] ^ 0x4f;
					buff[11] = tmp[26] ^ 0x93;
					break;
				case 4:
					buff[ 9] = tmp[27] ^ 0x70;
					buff[10] = tmp[28] ^ 0x4f;
					buff[11] = tmp[29] ^ 0x93;
					break;
				case 5:
					buff[10] = tmp[30] ^ 0x4f;
					buff[11] = tmp[31] ^ 0x93;
					break;
				case 6:
					buff[ 9] = tmp[32] ^ 0x70;
					buff[10] = tmp[33] ^ 0x4f;
					buff[11] = tmp[34] ^ 0x93;
					break;
				case 7:
					buff[10] = tmp[35] ^ 0x4f;
					buff[11] = tmp[36] ^ 0x93;
					break;
				case 8:
					buff[ 9] = tmp[37] ^ 0x70;
					buff[10] = tmp[38] ^ 0x4f;
					buff[11] = tmp[39] ^ 0x93;
					break;
			}
			while (1)
			{
			   	usb_control_msg(0xC0, GET_REMAINSPACE, 0, 0, &len ,1, 100);
				if (len >= 12)
				{
					usb_control_msg(0x40, PUT_DATA, 0, 0, buff, 12, 100);
					break;
				} else {
					usleep (30000);
				}
			}
		}

		while (1)
		{
		   	usb_control_msg(0xC0, GET_REMAINSPACE, 0, 0, &len ,1, 100);
			if (len >= 15)
			{
				usb_control_msg(0x40, PUT_DATA, 0, 0, &ConnectedMsg[11][0], 15, 100);
				break;
			} else {
				usleep(50000);
			}
		}

		/* PTT OFF */
		usb_control_msg(0x40, SET_PTT, OFF, 0, buff, 0, 100);
		PTT_On = FALSE;
}
